from django import forms
from django.utils.translation import ugettext as _

from jumbo.forms.models import ModelForm
from jumbo.apps.autocomplete import AutocompleteMultiChoiceField, autocomplete

import jumbo.middleware.thread_local as tl

from agenda.models import Appointment, Membership, Role, PERIODICITY, STATUS_MEM

autocomplete.register(
    'obj_member', Appointment.objects.all(), views = 'agenda.views.get_objmember', limit=10
)

class AppointmentAddForm(ModelForm):
    class Meta:
        model  = Appointment
        fields = (('title',),
                       ('description',),
                       ('date_begin','date_end'),
                       ('time_begin','time_end'),
                       ('periodicity',),)

    def __init__(self, *args, **kwargs):
        super(AppointmentAddForm, self).__init__(*args, **kwargs)
        self.fields['title'] = forms.CharField()
        self.fields['description'] = forms.CharField(required=False, widget=forms.Textarea(attrs={'class':'vLargeTextField'}))
        self.fields['date_begin'] = forms.DateField(widget=forms.DateInput)
        self.fields['date_end'] = forms.DateField()
        self.fields['time_begin'] = forms.TimeField()
        self.fields['time_end'] = forms.TimeField()
        self.fields['periodicity'] = forms.CharField(required=False, label=_("Periodicity"), widget=forms.Select(choices=PERIODICITY))
    
#    def save(self, formset=None):
#        request = tl.get_request()

class MembershipFormInline(ModelForm): 
    class Meta:
        model  = Membership
        fields = ('content_type', 'object_id', 'role', 'status', 'invite_reason')
    
    def __init__(self, *args, **kwargs):
        super(MembershipFormInline, self).__init__(*args, **kwargs)
        self.fields['obj_member'] = AutocompleteMultiChoiceField('obj_member', label=_("Oggetto"))
        self.fields['invite_reason'] = forms.CharField(label=_("Invito"))
        self.fields['role'] = forms.ModelChoiceField(queryset=Role.objects.all(), required=True, label=_("Ruolo"))
        self.fields['status'] = forms.CharField(required=False, widget=forms.Select(choices=STATUS_MEM), label=_("Stato"))
