import datetime

from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from admin_tools.menu import items, Menu
from jumbo.conf.admin_menu import GenericMenuItem
from jumbo.middleware.thread_local import get_current_user

def get_root_menu(children):
    user = get_current_user()
    if not user.has_perm("agenda.view_appointment"):
        return None

    root_menu = items.MenuItem(
        title=_('Agenda'),
        children=[],
        url = reverse('admin:agenda_appointment_changelist')
    )
    children.append(root_menu)

def add_extended_menuitems(children, current_app):
    gm = GenericMenuItem(current_app, [])
    user = get_current_user()

    list_appointments = items.MenuItem(
        title=_("List appointments"),
        children=[],
        url = reverse('admin:agenda_appointment_changelist')
    )
    today_appointment = items.MenuItem(
        title=_("Today's appointments"),
        children=[],
        url = "%sday/%s/" % (reverse('admin:agenda_appointment_calendar'), datetime.datetime.today().strftime("%Y%m%d"))
    )
    
    week_appointment = items.MenuItem(
        title=_("Week's appointments"),
        children=[],
        url = "%sweek/%s/" % (reverse('admin:agenda_appointment_calendar'), datetime.datetime.today().strftime("%Y%m%d"))
    )

    month_appointment = items.MenuItem(
        title=_("Month's appointments"),
        children=[],
        url = "%smonth/%s/" % (reverse('admin:agenda_appointment_calendar'), datetime.datetime.today().strftime("%Y%m%d"))
    )

    add_appointment = items.MenuItem(
        title=_("Add appointment"),
        children=[],
        url = reverse('admin:agenda_appointment_add')
    )

    # PERMESSI
    if user.has_perm("agenda.view_appointment"):
        gm.add_father(list_appointments)
        gm.add_father(today_appointment)
        gm.add_father(week_appointment)
        gm.add_father(month_appointment)
    if user.has_perm("agenda.add_appointment"):
        gm.add_father(add_appointment)

    menu = gm.get_menu()
    [ children.append(age_menu) for age_menu in menu ]
